@@ -1474,16 +1474,12 @@ If object is a lambda, return \"Anonymous\"."
 
 (defun helm-describe-class (class)
   "Display documentation of Eieio CLASS, a symbol or a string."
-  (let ((advicep (advice-member-p #'helm-source--cl--print-table 'cl--print-table)))
-    (unless advicep
-      (advice-add 'cl--print-table :override #'helm-source--cl--print-table '((depth . 100))))
-    (unwind-protect
-         (if (fboundp 'cl-describe-type)
-             (cl-describe-type (helm-symbolify class))
-           (let ((helm-describe-function-function 'describe-function))
-             (helm-describe-function (helm-symbolify class))))
-      (unless advicep
-        (advice-remove 'cl--print-table #'helm-source--cl--print-table)))))
+  (cl-letf (((symbol-function 'cl--print-table)
+             #'helm-source--cl--print-table))
+    (if (fboundp 'cl-describe-type)
+        (cl-describe-type (helm-symbolify class))
+      (let ((helm-describe-function-function 'describe-function))
+        (helm-describe-function (helm-symbolify class))))))
 
 (defun helm-describe-function (func)
   "Display documentation of FUNC, a symbol or string."
@@ -2024,7 +2020,10 @@ Directories expansion is not supported."
       (goto-char (point-min))
       (when (re-search-forward "^;;;?\\(.*\\) ---? \\(.*\\)" (pos-eol) t)
         (setq desc (match-string-no-properties 2)))
-      (if (or (null desc) (string= "" desc) (string-match "\\`-\\*-" desc))
+      (if (or (null desc) (string= "" desc)
+              ;; Fix issue#2716 with an header line like
+              ;; ";; foo --- -*-[...]" i.e. desc is not provided.
+              (string-match "\\`-\\*-" desc))
           "Not documented"
         (car (split-string desc "-\\*-" nil "[ \t\n\r-]+"))))))
 
@@ -2271,6 +2270,7 @@ flex or helm-flex completion style if present."
 (add-hook 'helm-cleanup-hook 'helm-reset-yank-point)
 (add-hook 'helm-after-initialize-hook 'helm-reset-yank-point)
 
+
 ;;; Ansi
 ;;
 ;;
